import React, { useState } from 'react'
import { Form, Select, Input, DatePicker, Row, Col, InputNumber, Checkbox } from 'antd'
const { Option } = Select
export default function StepFour({ syncDataForm }) {
  // 是否展示分区时间
  const [showPartitionTime, setShowPartitionTime] = useState(false)
  // 是否展示定时规则高级配置
  const [showRuleConfig, setShowRuleConfig] = useState(false)
  // 定时规则单位选择
  const suffixSelector = (
    <Select
      style={{
        width: 70,
      }}
      defaultValue="秒"
    >
      <Option value="秒">秒</Option>
      <Option value="分钟">分钟</Option>
      <Option value="小时">小时</Option>
      <Option value="日">日</Option>
      <Option value="周">周</Option>
      <Option value="月">月</Option>
    </Select>
  );
  return (
    <>
      <p
        style={{
          fontWeight: 600,
          borderLeft: '3px solid #1881DA',
          paddingLeft: '12px',
        }}>
        设置同步参数
      </p>
      <Form
        name="syncForm"
        form={syncDataForm}
        labelCol={{
          span: 2,
        }}
        wrapperCol={{
          span: 6,
        }}
        initialValues={{
          partition_info: '',
          replace_param: '',
          executor_timeout: 0,
          executor_fail_retry_count: 0,
          inc_start_time: ''
        }}
      >
        <Form.Item
          label="路由策略"
          name="executor_route_strategy"
          rules={[
            {
              required: true,
              message: '请选择路由策略',
            },
          ]}>
          <Select
            options={[
              {label: '第一个', value: 'FIRST'},
              {label: '最后一个', value: 'LAST'}
            ]}
            allowClear
            placeholder='请选择路由策略'
          />
        </Form.Item>
        <Form.Item
          label="阻塞处理方式"
          name="executor_block_strategy"
          rules={[
            {
              required: true,
              message: '请选择阻塞处理方式',
            },
          ]}>
          <Select
            options={[
              {label: '单机串行', value: 'SERIAL_EXECUTION'},
              {label: '丢弃后续调度', value: 'SERIAL_EXECUTION1'},
              {label: '覆盖之前调度', value: 'SERIAL_EXECUTION2'},
            ]}
            allowClear
            placeholder='请选择阻塞处理方式'
          />
        </Form.Item>
        <Form.Item
          label="超时时间"
          name="executor_timeout"
          required
        >
          <InputNumber min={0} addonAfter="分钟"/>
        </Form.Item>
        <Form.Item
          label="失败重试次数"
          name="executor_fail_retry_count"
          required
        >
          <InputNumber  min={0} addonAfter="次" />
        </Form.Item>
        <Form.Item
          label="增量开始时间"
          name="inc_start_time"
        >
          <DatePicker showTime placeholder='请选择增量开始时间'/>
        </Form.Item>
        <Form.Item
          label="增量时间字段"
          name="replace_param"
        >
          <Input placeholder="-DlastTime='%s' -DcurrentTime='%s'"/>
        </Form.Item>
        <Row span={24}>
          <Col span={8}>
            <Form.Item
              label="区分字段"
              name="partition_info"
              labelCol={{
                span: 6,
              }}
              wrapperCol={{
                span: 18,
              }}>
              <Input
                onChange={e => {
                  if (e.target.value && !showPartitionTime) {
                    setShowPartitionTime(true)
                  } else if (!e.target.value && showPartitionTime) {
                    setShowPartitionTime(false)
                  }
                }}
                placeholder='请输入区分字段'
              />
            </Form.Item>
          </Col>
          {showPartitionTime ? (
            <>
              <Col span={8}>
                <Form.Item
                  label="分区时间"
                  name="partition_time"
                  labelCol={{
                    span: 12,
                  }}
                  wrapperCol={{
                    span: 12,
                  }}>
                  <Select
                    options={[
                      {label: 'yyyy-MM-dd', value: 'yyyy-MM-dd'},
                      {label: 'yyyyMMdd', value: 'yyyyMMdd'},
                      {label: 'yyyy/MM/dd', value: 'yyyy/MM/dd'},
                    ]}
                    allowClear
                    defaultValue={'yyyy-MM-dd'}
                  />
                </Form.Item>
              </Col>
              <Col>
                <InputNumber defaultValue={0} style={{ marginLeft: '10px' }} max={0}/>
              </Col>
            </>
          ) : (
            ''
          )}
        </Row>
        <Row span={24}>
          <Col span={8}>
            <Form.Item
              label="定时规则"
              name="job_cron"
              labelCol={{
                span: 6,
              }}
              wrapperCol={{
                span: 18,
              }}
              rules={[
                {
                  required: true,
                  message: '请输入定时规则',
                },
              ]}>
              {showRuleConfig ? <Input placeholder='请输入定时规则'/> : <InputNumber
                min={0}
                addonAfter={suffixSelector}
                placeholder='请输入定时规则'
                style={{ width: '100%',}}
              />}
            </Form.Item>
          </Col>
          <Col span={8} style={{marginLeft: '20px'}}>
            <Form.Item labelCol={{span: 3}}>
              <Checkbox checked={showRuleConfig} onChange={(e) => {setShowRuleConfig(e.target.checked)}}>高级配置</Checkbox>
            </Form.Item>
          </Col>
        </Row>
        
        <Form.Item
          label="同步任务名称"
          name="job_desc"
          rules={[
            {
              required: true,
              message: '请输入定时规则',
            },
          ]}>
          <Input placeholder='请输入同步任务名称' />
        </Form.Item>
      </Form>
    </>
  )
}
