import React, { useState } from 'react'
import { Form, Select, Button, Space } from 'antd'
import TaskForm from './TaskForm'
import TaskChartEditor from './TaskChartEditor'
import styled from 'styled-components'
import { useNavigate } from 'react-router'

const TaskCreater = styled.div`
  margin: 20px;
  background: #fff;
  height: 100%;
  padding: 15px 25px;
  .tasktype_label {
    padding-left: 12px;
    border-left: 3px solid #1881da;
    font-size: 14px;
    font-family: PingFangSC-Medium, PingFang SC;
    font-weight: 500;
    color: #4a4a4a;
    line-height: 20px;
    letter-spacing: 1px;
  }
  .tasktype_form {
    margin-top: 20px;
  }
  .tasktype_btns {
    margin: 20px 20px 0px;
  }
`

const layout = {
  labelCol: {
    span: 2,
  },
  wrapperCol: {
    span: 8,
  },
}

const FormItem = Form.Item
const { Option } = Select

const TaskCreaterView = () => {
  // 路由导航
  const navigate = useNavigate()

  const [taskType, setTaskType] = useState(null)
  const [taskTypeForm] = Form.useForm()
  const [taskForm] = Form.useForm()
  const onTaskTypeChange = value => {
    setTaskType(value)
  }
  const onSubmit = () => {
    navigate(-1)
  }
  return (
    <TaskCreater>
      <div className="tasktype_label">配置任务类型：</div>
      <Form {...layout} form={taskTypeForm} className="tasktype_form">
        <FormItem
          name="taskType"
          label="选择任务类型"
          rules={[{ required: true, message: '请选择任务类型!' }]}>
          <Select
            placeholder="选择任务类型"
            onChange={onTaskTypeChange}
            allowClear>
            <Option value="singleTask">单作业离线任务</Option>
            <Option value="multitasking">多作业离线任务</Option>
          </Select>
        </FormItem>
      </Form>
      <div className="tasktype_label">配置任务信息：</div>
      <TaskForm taskForm={taskForm} taskType={taskType} />
      {taskType === 'multitasking' && (
        <div className="tasktype_label">作业编排：</div>
      )}
      {taskType === 'multitasking' && <TaskChartEditor />}
      <Space className="tasktype_btns">
        <Button onClick={() => navigate(-1)}>取消</Button>
        <Button onClick={onSubmit}>提交</Button>
      </Space>
    </TaskCreater>
  )
}

export default TaskCreaterView
