import React, { useState } from 'react'
import { Table, Switch, Space, Button } from 'antd'
import { Link } from 'react-router-dom'
import styled from 'styled-components'
import errImgUrl from '../style/img/err.png'
import successImgUrl from '../style/img/success.png'

const TaskMgmtWrapper = styled.div`
  padding: 20px;
  .icon_wrapper {
    margin-right: 15px;
  }
  .link_btn {
    display: flex;
    justify-content: end;
    margin-bottom: 20px;
  }
`
const data = [
  {
    key: 1,
    taskName: '每日供应商销量预测任务',
    taskType: '单作业离线任务',
    taskTag: '业务预测',
    executionCycle: '循环触发，1小时',
    historicalRuntime: [1, 0, 1, 1, 1, 1, 1, 0, 0, 1],
    taskState: false,
  },
  {
    key: 2,
    taskName: 'AI平台算法服务定时监测',
    taskType: '多作业离线任务',
    taskTag: '任务监测',
    executionCycle: '循环触发6小时',
    historicalRuntime: [1, 1, 1, 0, 0, 1],
    taskState: true,
  },
]

const TaskMgmtView = () => {
  // 表格Loading状态
  const [dataLoading, setDataLoading] = useState(false)

  const columns = [
    {
      title: '任务名称',
      dataIndex: 'taskName',
      key: 'taskName',
    },
    {
      title: '任务类型',
      dataIndex: 'taskType',
      key: 'taskType',
    },
    {
      title: '任务分类',
      dataIndex: 'taskTag',
      key: 'taskTag',
    },
    {
      title: '执行周期',
      dataIndex: 'executionCycle',
      key: 'executionCycle',
    },
    {
      title: '历史运行情况',
      dataIndex: 'historicalRuntime',
      key: 'historicalRuntime',
      render: list => (
        <div>
          {list.map((item, index) => {
            return (
              <img
                key={index}
                src={item === 0 ? errImgUrl : successImgUrl}
                alt=""
                className="icon_wrapper"
              />
            )
          })}
        </div>
      ),
    },
    {
      title: '状态',
      dataIndex: 'taskState',
      key: 'taskState',
      render: val => (
        <Switch
          checkedChildren="开启"
          unCheckedChildren="关闭"
          defaultChecked={val}
          onChange={changeTaskState}
        />
      ),
    },
    {
      title: '操作',
      key: 'operation',
      render: (_, record) => (
        <Space size="middle">
          <span
            onClick={() => {
              runTimeOnce(record.key)
            }}
            style={{ color: '#1881DA', cursor: 'pointer' }}>
            执行一次
          </span>
          <span
            onClick={() => {
              editTask(record.key)
            }}
            style={{ color: '#1881DA', cursor: 'pointer' }}>
            编辑
          </span>
          <span
            onClick={() => {
              deleteTask(record.key)
            }}
            style={{ color: '#1881DA', cursor: 'pointer' }}>
            删除
          </span>
          <span
            onClick={() => {
              getApiUri(record.key)
            }}
            style={{ color: '#1881DA', cursor: 'pointer' }}>
            API调用
          </span>
        </Space>
      ),
    },
  ]
  // 切换状态
  const changeTaskState = checked => {
    console.log(checked)
  }
  //执行
  const runTimeOnce = id => {
    console.log('runtime', id)
  }
  //删除
  const deleteTask = id => {
    console.log('delete', id)
  }
  //Api调用
  const getApiUri = id => {
    console.log('api', id)
  }
  //编辑
  const editTask = id => {
    console.log('edit', id)
  }

  return (
    <TaskMgmtWrapper>
      <div className="link_btn">
        <Link to="/task-mgmt/create-task">
          <Button type="primary">创建离线任务</Button>
        </Link>
      </div>
      <Table
        columns={columns}
        dataSource={data}
        bordered
        loading={dataLoading}
      />
    </TaskMgmtWrapper>
  )
}

export default TaskMgmtView
